from setuptools import setup ,find_packages



setup(

name = "pycosmic",
version="3.3.0",
description="Packages That Shortens The Code  ",
author="Rishabh",
author_email="rishivisionworld@gmail.com",
install_requires=['qrcode','opencv-python'],
packages=find_packages(),


)